#!/bin/ksh
#------------------------------------------------------------------------------
#
# Licensed Materials - Property of IBM Corp.
# (C) Copyright IBM Corp. 2004, 2012
#
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# ABSTRACT:
#    This Korn Shell Script is a wrapper script which is called to
#    set up the environment for the user properly before invoking
#    the command amldapsearch.
#
# #### DO NOT EDIT THIS FILE ####
#-------------------------------------------------------------------------------

# ###############################################################
# Set up some initial global environment variables we may need
# Based on the operating system.
# ###############################################################

# Get the OS Name.  We have to assume uname is alway avaliable.
OS=`uname -s`
unset  GSKIT_LOCAL_INSTALL_MODE

#------- Globals ----------
integer rc=0

# Set the name of the program to run.
PROGNAME="amldapsearch"

# Where the IBM Security Access Manager is installed.
ISAM_HOME=/opt/PolicyDirector

#------- Shell commands -------
# Set up variables based on the OS.
SUPPORTEDDB2LEVEL=9

if [ "${OS}" = "Linux" ] ; then
  # LINUX
  CUT=/usr/bin/cut
  MV=/bin/mv
  MKDIR=/bin/mkdir
  CHOWN=/bin/chown
  CHMOD=/bin/chmod
  RM=/bin/rm
  DATE=/bin/date
  CD=cd
  LS=ls
  GREP=/bin/grep
  SED=/bin/sed
  CAT=/bin/cat
  HEAD=/usr/bin/head
  WHICH=/usr/bin/which
  WHENCE=whence
  BASENAME=/bin/basename
  DIRNAME=/usr/bin/dirname
  AWK=/bin/awk
  ENV=env
  XDIR=/usr/bin/X11
  IS64BIT=`uname -m`
elif [ "${OS}" = "HP-UX" ] ; then
  # HP-UX
  CUT=/bin/cut
  MV=/bin/mv
  MKDIR=/bin/mkdir
  CHOWN=/bin/chown
  CHMOD=/bin/chmod
  RM=/bin/rm
  DATE=/bin/date
  CD=cd
  LS=/bin/ls
  GREP=/usr/bin/grep
  SED=/usr/bin/sed
  CAT=/usr/bin/cat
  HEAD=/usr/bin/head
  WHICH=/bin/which
  WHENCE=whence
  BASENAME=/usr/bin/basename
  DIRNAME=/usr/bin/dirname
  AWK=/usr/bin/awk
  ENV=env
  XDIR=/usr/bin/X11
  IS64BIT=`/usr/bin/getconf KERNEL_BITS`
  HP_HWCHECK=`uname -m`
  set +u
elif [ "${OS}" = "SunOS" ] ; then
  # Solaris
  CUT=/usr/bin/cut
  MV=/usr/bin/mv
  MKDIR=/usr/bin/mkdir
  CHOWN=/usr/bin/chown
  CHMOD=/usr/bin/chmod
  RM=/usr/bin/rm
  DATE=/usr/bin/date
  CD=cd
  ENV=env
  LS=/usr/bin/ls
  GREP=/usr/bin/grep
  SED=/usr/bin/sed
  CAT=/usr/bin/cat
  HEAD=/usr/bin/head
  WHICH=/usr/bin/which
  WHENCE=whence
  BASENAME=/usr/bin/basename
  DIRNAME=/usr/bin/dirname
  AWK=/usr/bin/awk
  XDIR=/usr/openwin/bin
  IS64BIT=`/usr/bin/isainfo -b`
elif [[ "${OS}" = "AIX" || "${OS}" = "OS400" ]] ; then
  # AIX or OS/400 PACE
  CUT=/usr/bin/cut
  MV=/usr/bin/mv
  MKDIR=/usr/bin/mkdir
  CHOWN=/usr/bin/chown
  CHMOD=/usr/bin/chmod
  RM=/usr/bin/rm
  DATE=/usr/bin/date
  CD=cd
  ENV=env
  LS=/usr/bin/ls
  GREP=/usr/bin/grep
  SED=/usr/bin/sed
  CAT=/usr/bin/cat
  HEAD=/usr/bin/head
  WHICH=/usr/bin/which
  WHENCE=whence
  BASENAME=/usr/bin/basename
  DIRNAME=/usr/bin/dirname
  AWK=/usr/bin/awk
  XDIR=/usr/bin/X11
  AIXVERSION=`uname -v`
  AIXRELEASE=`uname -r`
  if [ "${OS}" = "AIX" ] ; then
    if [[ ${AIXVERSION} -gt 4 ]] ; then
      if [[ ${AIXRELEASE} -gt 1 ]] ; then
        IS64BIT=`/usr/bin/getconf KERNEL_BITMODE`
      else
        IS64BIT=`/bin/ls -l /usr/lib/boot/unix | /usr/bin/awk '{print $11}' | /usr/bin/tr -s "//" | /usr/bin/cut -f 5 -d "//"`
      fi
    else
      IS64BIT=32
    fi
  else
    # For now, OS/400 Pace is always 32-bit.
    IS64BIT=32
  fi
else
  # We have an unsupported platform
  # Print a message and exit.
  if [[ "${OS}" = "" && "${PROGNAME}" = "tbindmsg" ]] ; then
    ACTION_MSG="GLPWRP001E Cannot run tbindmsg wrapper script due to unable to run uname command (PATH error?)"
  else
    ACTION_MSG=`/opt/IBM/ldap/V6.3/bin/tbindmsg wrapper 1 1 "GLPWRP001E Ran wrapper script on an unsupported operating system: %1\\\$s\n" "$OS"`
  fi
  echo "$ACTION_MSG"
  exit 1
fi

# Set the type of program it is so that the wrapper script can set extra stuff
# up if needed.
PROGTYPE="c"

# If the directory is bin, we are a client application.
ITDS_INST_BIN=bin

# Set to true if the program needs the DB2 libraries set.
NEEDDB2LIBS="false"

# Set to true if the program needs the instance specific
# DB2 libraries.
NEEDINSTDB2LIBS="false"

# Set to true if the program needs to load the
# db2 specifed in the backed up file
NEEDBACKEDUPDB2LIBS=""

# Set current TDS Version
TDS_VERSION=6.3

# Set default value of PrintUsage to false
PRINT_USAGE="false"

# Set default value of PrintVersion to false
PRINT_VERSION="false"

# Flag to identify  -x option for idsicrt command line option
PROXY_INST="false"

# Variable to indicate if the call to get default instance name was made or not
GETDEFINST_WASCALLED='n'

# Set the repository path
if [ "${OS}" = "Linux" ] ; then
   REP_PATH=/opt/ibm/ldap/idsinstinfo/idsinstances.ldif
else
   REP_PATH=/opt/IBM/ldap/idsinstinfo/idsinstances.ldif
fi

# -- Uncomment the following three lines if SIGABORTS occur on Linux platform
#    while running a java program.
# if [ "${OS}" = "Linux" ] ; then
#    export LD_PRELOAD=/usr/lib/libstdc++-libc6.2-2.so.3
# fi

# Function Determines where the IBM Tivoli Directory Server V6.3
# is installed.  It will assume the IDS_LDAP_HOME variable is
# the install location if it is already set.
GetITDSHOME()
{
  # Only change this if it has not already been set.
  if [ "$IDS_LDAP_HOME"  = "" ] ; then
    export IDS_LDAP_HOME=/opt/IBM/ldap/V6.3
  fi
}
# Function Determines where the IBM Tivoli Integrator Server
# is installed.  It will assume the IDS_LDAP_TDI_HOME variable is
# the install location if it is already set.
GetITDIHOME()
{
  # Only change this if it has not already been set.
  if [ "$IDS_LDAP_TDI_HOME"  = "" ] ; then
    export IDS_LDAP_TDI_HOME=/opt/IBM/TDI/V7.1
  fi
}

# Function retrieves the instance location.
# not used by client utilities.
function GetInstanceLocation {

    GetMigInstanceLocation $1

    if [[ $found = 'n' && -n $name ]]
     then
        ACTION_MSG=`${IDS_LDAP_HOME}/bin/tbindmsg wrapper 1 7 "GLPWRP007E The instance %1\\\$s is not created or could not be found.\n" "$name"`
        echo "$ACTION_MSG"
        exit 1
     fi

}
function GetMigInstanceLocation {
    name=$1
    file=$REP_PATH
    found='n'
    typeset l attr
    # Read the file
    if [[ -r $file ]]
    then
        while read attr value;
        do
            if [[ "$attr" = "cn:" && "$value" = "$name" ]]
            then
                found='y'
                continue
            fi
            if [[ $found = 'y' && "$attr" = "ids-instanceLocation:" ]]
            then
                location=$value
                export location
                break
            fi
        done < $file
    fi

    export found

}

# Function checks the repository for the default instance name
# Not used by client utilities
ReadInstanceName()
{
    name1="CN=IDS"
    name2="INSTANCES"
    file=$REP_PATH
    found='n'
    typeset l attr
    # Read the file
    if [[ -r $file ]]
    then
	while read attr value1 value2;
	do
	   if [[ "$attr" = "dn:" ]]
	   then
	      if [[ "$value1" = "$name1" && "$value2" = "$name2" ]]
	      then
	         continue
	      else
	         found='y'
              fi
           fi
	   if [[ $found = 'y' && "$attr" = "cn:" ]]
	   then
	      instname=$value1
	      export instname
	      break
	   fi
	done < $file
    fi
    GETDEFINST_WASCALLED='y'
}


#Function checks the repository for the instance version
GetInstanceTDSVersion()
{
#input : instance name
#output : directory server version for associated instance
    instancename=$1
    file=$REP_PATH
    found='n'
    typeset l attr
    # Read the file
    if [[ -r $file ]]
    then
        while read attr value
        do
           if [[ "$attr" = "cn:" && "$value" = "$instancename" ]]
           then
                 found='y'
           fi

           if [[ $found = 'y' && "$attr" = "ids-instanceVersion:" ]]
           then
              instversion=$value
              export instversion
              break
           fi
        done < $file
    fi
}

#Function checks the ibmslapd.conf for the instance type (proxy or rdbm backend)
GetInstanceType()
{
 #Input: instance name
 #output: instance type (proxy or rdbm backend)
 instanceName=$1
 instanceLocation=$2
 found='n'

 if [[ "$instConfFile" != "" ]]
 then
     file=$instConfFile
 elif [[ -f ${backdir}/etc/ibmslapd.conf ]] ; then
     file=${backdir}/etc/ibmslapd.conf
 else
     file=$instanceLocation/idsslapd-$instanceName/etc/ibmslapd.conf
 fi


 #Read the file
 if [[ -r $file ]] ; then
    while read attr value
    do
      if [[ "$attr" = "dn:" && "$value" = "cn=Configuration" ]]
      then
            found='y'
      fi

      if [[ $found = 'y' && "$attr" = "ibm-slapdServerBackend:" ]]
      then
         instanceType=$value
         export instanceType
         break
      fi
    done < $file

    if [[ $found = 'n' ]]
    then
       ACTION_MSG=`${IDS_LDAP_HOME}/bin/tbindmsg wrapper 1 9 "GLPWRP009E The instance type (PROXY or RDBM) for instance %1\\\$s was not found.\n" "$instanceName"`
       echo "$ACTION_MSG"
       exit 1
    fi
 else
   #If the file does not exist, then a migration is being tried with a dropped
   #TDS 6.0 instance. Hence, do not exit.
   ACTION_MSG=`${IDS_LDAP_HOME}/bin/tbindmsg wrapper 1 9 "GLPWRP009E The instance type (PROXY or RDBM) for instance %1\\\$s was not found.\n" "$instanceName"`
   echo "$ACTION_MSG"
 fi
}

BackupAndClearLIBPATH()
{
   if [ "${OS}" = "Linux" ] ; then
      export BKUP_LD_LIBRARY_PATH=${LD_LIBRARY_PATH}
      export LD_LIBRARY_PATH=
   elif [ "${OS}" = "HP-UX" ] ; then
      export BKUP_LD_LIBRARY_PATH=${SHLIB_PATH}
      export BKUP_SHLIB_PATH=${SHLIB_PATH}
      export LD_LIBRARY_PATH=
      export SHLIB_PATH=
   elif [ "${OS}" = "SunOS" ] ; then
      export BKUP_LD_LIBRARY_PATH=${LD_LIBRARY_PATH}
      export LD_LIBRARY_PATH=
   else
      export BKUP_LIBPATH=${LIBPATH}
      export LIBPATH=
   fi
}

RestoreLIBPATH()
{
   if [ "${OS}" = "Linux" ] ; then
      export LD_LIBRARY_PATH=${BKUP_LD_LIBRARY_PATH}
   elif [ "${OS}" = "HP-UX" ] ; then
      export LD_LIBRARY_PATH=${BKUP_LD_LIBRARY_PATH}
      export SHLIB_PATH=${BKUP_SHLIB_PATH}
   elif [ "${OS}" = "SunOS" ] ; then
      export LD_LIBRARY_PATH=${BKUP_LD_LIBRARY_PATH}
   else
      export LIBPATH=${BKUP_LIBPATH}
   fi
}

#Function retrieves the DB2 installpath and DB2 version.
#Not used by client utilities
GetDB2InstallPathAndVersion()
{
   #Input : ldapdb.properties file location
   #Output: DB2 installpath and version retrieved

   file=$1

   if [[ -r $file ]] ; then
      while read line;
      do
         attr=`echo $line|cut -f1 -d'='|cut -f1 -d' '`
         value=`echo $line|cut -f2 -d'='|cut -f2 -d' '`

         if [[ "$attr" = "currentDB2InstallPath" ]] ; then
            DB2PATH=$value
            export DB2PATH
         fi

         if [[ "$attr" = "currentDB2Version" ]] ; then
            version=`echo $value|cut -f1 -d'.'`
            DB2VERSION=$version
            export DB2VERSION
         fi
      done < $file
   else
      ACTION_MSG=`/opt/IBM/ldap/V6.3/bin/tbindmsg wrapper 1 6 "GLPWRP006E The DB2 property file '%1\\\$s' is not available.\n" "$file"`
      echo "$ACTION_MSG"
      exit 1
   fi

   if [[ "${DB2VERSION}" -gt 8 ]]; then
      if [[ -r ${DB2PATH}/adm/db2set ]] ; then
         BackupAndClearLIBPATH
         ${DB2PATH}/adm/db2set -g DB2INSTDEF=
         RestoreLIBPATH
      fi
   fi
}
# Function retrieves the instance name.
# Not used by client utilities.
GetInstanceName()
{
   # Check env variable for instance name.
   if( ${ENV}|${GREP} ^IDS_LDAP_INSTANCE= > /dev/null 2>&1 ) ; then
     instname=$IDS_LDAP_INSTANCE
     export instname
   else
     # Try and get the instance name from the repository
     ReadInstanceName
   fi
}


# Function to set the DB2 Path assuming setting as per global properties file.
SetDB2Path()
{
   if [[ "${DB2VERSION}" -gt 8 && "${ITDS_LIB}" = "lib" ]] ; then
      DB2_LIB=lib32
   else
      DB2_LIB=$ITDS_LIB
   fi

   if [ "${OS}" = "Linux" ] ; then
      LD_LIBRARY_PATH=${DB2PATH}/${DB2_LIB}:${LD_LIBRARY_PATH}
      if [[ "${IS64BIT}" = "s390x" ]];then
         LD_LIBRARY_PATH=${DB2PATH}/lib:${LD_LIBRARY_PATH}
      fi
   elif [ "${OS}" = "HP-UX" ] ; then
      SHLIB_PATH=${DB2PATH}/${DB2_LIB}:${SHLIB_PATH}
   elif [ "${OS}" = "SunOS" ] ; then
      LD_LIBRARY_PATH=${DB2PATH}/${DB2_LIB}:${LD_LIBRARY_PATH}
   else
      LIBPATH=${DB2PATH}/${DB2_LIB}:${LIBPATH}
   fi
}

# Function to get the install path from Global properties file and set it in
# environment
GetAndSetDB2Path()
{
   GetDB2InstallPathAndVersion ${IDS_LDAP_HOME}/etc/ldapdb.properties
   if [ "${DB2VERSION}" -lt "${SUPPORTEDDB2LEVEL}" ] ; then
      ACTION_MSG=`/opt/IBM/ldap/V6.3/bin/tbindmsg wrapper 1 13 "GLPWRP013E DB2 versions prior to 9.1 are not supported.
"`
      echo "$ACTION_MSG"
      exit 1
   fi

   SetDB2Path
}

# Function to manage the core files and change the current directory to the {inst home}/workdir
ManageCoreFiles()
{
MCF_CORE_FILE="core"
integer MAX_ARCHIVE_CORES=2
MCF_INST_HOME=${INST_LOCATION}/idsslapd-${INST_NAME}
MCF_WORK_DIR=${MCF_INST_HOME}/workdir
MCF_TIMESTAMP=`$DATE +%Y-%m-%d-%H_%M_%S`
MCF_INST_OWNERS_GRP=`$GREP ^${INST_NAME}: /etc/passwd | $CUT -f4 -d:`

   # only attempt to manage the core file if user has authority
   if [[ ( ! -w ${MCF_INST_HOME}) || ( ! -x ${MCF_INST_HOME}) || ( ! -r ${MCF_INST_HOME}) ]] ; then
      return
   fi

   # Make sure the workdir exists
   if [[ ( ! -a $MCF_WORK_DIR ) ]] ; then
      $MKDIR $MCF_WORK_DIR
      # if the current user (like root) is not the owner of the inst home then
      # set the ownership to the inst owner
      if [[ ( ! -O ${MCF_INST_HOME}) ]] ; then
         $CHOWN ${INST_NAME}:${MCF_INST_OWNERS_GRP} $MCF_WORK_DIR >/dev/null 2>&1
         $CHMOD 770 $MCF_WORK_DIR >/dev/null 2>&1
      fi
   fi

 if [ "${OS}" = "Linux" ] ; then
        $LS $MCF_WORK_DIR | $GREP $MCF_CORE_FILE > $MCF_WORK_DIR/list.txt
        $GREP "core" $MCF_WORK_DIR/list.txt > /dev/null
        exists=$?

          if [[ ( -a $MCF_WORK_DIR/list.txt ) ]] ; then
             $RM $MCF_WORK_DIR/list.txt
          fi
        if [[ $exists -ne 1 ]] ; then

	  # first get an array list of the archived file if any
          # the for loop determines if there are any archived core files
          integer nop=1
          integer cnt=0

	    ## rename part is here

             set -A corefiles `find ${MCF_WORK_DIR}/* ! -name  "*\_*"`
             lincore=${#corefiles[*]}

                while (($cnt < $lincore));
                do
		   $LS ${corefiles[cnt]} | $GREP "core" >/dev/null
	           onlycore=$?
		   if [[ $onlycore -ne 1 ]] ; then
		      if [[ -d ${file[cnt]} ]]; then
                         ""
                      else
                         $MV ${corefiles[cnt]} ${corefiles[cnt]}._${MCF_TIMESTAMP}  >/dev/null 2>&1
		      fi
		   fi
                   (( cnt=cnt+1 ))
                done
          # first get an array list of the archived file if any
         # the for loop determines if there are any archived core files

	set -A archcorefiles `find ${MCF_WORK_DIR}/*  -name  "*\_*"`

         integer archivecount=${#archcorefiles[*]}
         integer lastarchivecount=$archivecount
         (( lastarchivecount=lastarchivecount+1 ))

   	 # go through all the archived core files to find the oldest archive
         # in case the rm failed the lastarchivecount will = archivecount so
         # don't go into infinite loop

         while (( archivecount > MAX_ARCHIVE_CORES && lastarchivecount > archivecount ))
         do
            integer cur=1
            integer older=0
            while (( cur < ${#archcorefiles[*]} ))
            do
               if [[ ${archcorefiles[$older]} -nt ${archcorefiles[cur]} ]] ; then
                  (( older=cur ))
               fi
               (( cur=cur+1 ))
            done
            # remove the oldest file if user has write access
            if [[ ( -w ${archcorefiles[$older]} ) ]] ; then
               $RM ${archcorefiles[$older]}  >/dev/null 2>&1
            else
	       ACTION_MSG=`${IDS_LDAP_HOME}/bin/tbindmsg wrapper 1 4 "GLPWRP004W Could not remove oldest archived core file because write access is needed for: %1\\\$s.\n" "${archcorefiles[$older]}"`
               echo "$ACTION_MSG"
            fi

            # get the new list archived files since one was been removed
            # the for loop determines if there are any archived core files

	    set -A archcorefiles `find ${MCF_WORK_DIR}/*  -name  "*\_*"`

	    # reset the archivecount variable
            (( lastarchivecount=archivecount ))
            (( archivecount=${#archcorefiles[*]} ))

         done

        fi

      fi  ## end linux

 if [ "${OS}" != "Linux" ] ; then

# Make sure if core files exist then save it under a different name and
# limit the # of saved cores
  if [[ ( -a ${MCF_WORK_DIR}/${MCF_CORE_FILE} ) ]] ; then

  # remove the oldest saved core if the core count is greater than the max. allowed

  # first get an array list of the archived file if any
  # the for loop determines if there are any archived core files
     integer nop=1
     for tmparchivecorefiles in ${MCF_WORK_DIR}/${MCF_CORE_FILE}._*
     do
       (( nop = nop ))
       done
       # if the tmparchivecorefiles is equal to ${MCF_WORK_DIR}/${MCF_CORE_FILE}._* then
       #there are no archives
       if [[ $tmparchivecorefiles != "${MCF_WORK_DIR}/${MCF_CORE_FILE}._*" ]] ; then
          set -A archivecorefiles $($LS ${MCF_WORK_DIR}/${MCF_CORE_FILE}._*)
       else
          set -A archivecorefiles
       fi

       integer archivecount=${#archivecorefiles[*]}
       integer lastarchivecount=$archivecount
       (( lastarchivecount=lastarchivecount+1 ))
       # go through all the archived core files to find the oldest archive
       # in case the rm failed the lastarchivecount will = archivecount so
       # don't go into infinite loop
       while (( archivecount >= MAX_ARCHIVE_CORES && lastarchivecount > archivecount ))
       do
         integer cur=1
         integer older=0
         while (( cur < ${#archivecorefiles[*]} ))
         do
           if [[ ${archivecorefiles[$older]} -nt ${archivecorefiles[cur]} ]] ; then
              (( older=cur ))
           fi
           (( cur=cur+1 ))
         done
         # remove the oldest file if user has write access
         if [[ ( -w ${archivecorefiles[$older]} ) ]] ; then
            $RM ${archivecorefiles[$older]}  >/dev/null 2>&1
         else
            ACTION_MSG=`${IDS_LDAP_HOME}/bin/tbindmsg wrapper 1 4 "GLPWRP004W Could not remove oldest archived core file because write access is needed for: %1\\\$s.\n" "${archivecorefiles[$older]}"`
            echo "$ACTION_MSG"
         fi

         # get the new list archived files since one was been removed
         # the for loop determines if there are any archived core files
         for tmparchivecorefiles in ${MCF_WORK_DIR}/${MCF_CORE_FILE}._*
         do
           (( nop = nop ))
         done
         # if the tmparchivecorefiles is equal to ${MCF_WORK_DIR}/${MCF_CORE_FILE}._* then
         # there are no archives
         if [[ $tmparchivecorefiles != "${MCF_WORK_DIR}/${MCF_CORE_FILE}._*" ]] ; then
            set -A archivecorefiles $($LS ${MCF_WORK_DIR}/${MCF_CORE_FILE}._*)
         else
            set -A archivecorefiles
         fi
         # reset the archivecount variable
         (( lastarchivecount=archivecount ))
         (( archivecount=${#archivecorefiles[*]} ))
       done

       #do the renaming if the rm worked or the maximum archive file count has not been reached
       if (( lastarchivecount != archivecount )) ; then
          $MV ${MCF_WORK_DIR}/${MCF_CORE_FILE} ${MCF_WORK_DIR}/${MCF_CORE_FILE}._${MCF_TIMESTAMP}  >/dev/null 2>&1
       fi

     fi

   fi

# change the current directory to the workdir so that the core files will be placed there
$CD ${MCF_WORK_DIR}  >/dev/null 2>&1

}

############################################################################
#  Main code starts here
############################################################################

# 1) determine IDS_LDAP_HOME
GetITDSHOME

# 2) Set some extra stuff if this is a java program.
if [ "${PROGTYPE}" = "java" ] ; then
  if [ "$JAVA_FONT_OFFSET" = "" ] ; then
    #-------------------------------------------------------------------
    # Set up the JAVA_FONT_OFFSET.
    # This variable is set because on 4.3 systems, text in the multibyte
    # locales is illegible if the default offset from java is used.
    #-------------------------------------------------------------------
    JAVA_FONT_OFFSET=0
    case $LANG in
          ja_JP ) JAVA_FONT_OFFSET=-4
                ;;
          Ja_JP ) JAVA_FONT_OFFSET=-4
                ;;
          JA_JP ) JAVA_FONT_OFFSET=-4
                ;;
    esac
    export JAVA_FONT_OFFSET
  fi

  #----------------------------------------------------
  # Turn native threads off on Sparc.
  # DB2 may inadvertently turn it on
  #----------------------------------------------------
  if [ "${OS}" = "SunOS" ] ; then
     unset THREADS_FLAG
  fi

  #----------------------------------------------------
  # Set some other Java envs.
  #----------------------------------------------------
  JVM=${IDS_LDAP_HOME}/java/jre/bin/java
  if [[ "${OS}" = "SunOS" || "${OS}" = "HP-UX" ]] ; then
    JVM="${JVM} -d64"
  fi
  JVMTEST=${IDS_LDAP_HOME}/java/jre/bin/java
  JAVA_HOME=${IDS_LDAP_HOME}/java
  export JAVA_HOME
  JAVA_HOME_BIN=${JAVA_HOME}/bin
  export JAVA_HOME_BIN
  JAVA_HOME_CLASSIC=${JAVA_HOME}/bin/classic
  export JAVA_HOME_CLASSIC

  # See what lang to pass through.
  if [ "$LANG"  != "" ] ; then
    JVM="${JVM} -Denv.lang=${LANG}"
  else
    JVM="${JVM} -Denv.lang=en_US"
  fi

  # For HP - To ensure shortcut keys - mnemonics work. (D91388)
  if [ "${OS}" = "HP-UX" ] ; then
    JVM="${JVM} -Dhpux.im.disable=true "
  fi

  # Set up a library path for the JVM.
  if [ "${OS}" = "Linux" ] ; then
    LD_LIBRARY_PATH=${JAVA_HOME_BIN}:${JAVA_HOME_CLASSIC}:${LD_LIBRARY_PATH}
  elif [ "${OS}" = "HP-UX" ] ; then
    SHLIB_PATH=${JAVA_HOME_BIN}:${JAVA_HOME_CLASSIC}:${SHLIB_PATH}
  elif [ "${OS}" = "SunOS" ] ; then
    LD_LIBRARY_PATH=${JAVA_HOME_BIN}:${JAVA_HOME_CLASSIC}:${LD_LIBRARY_PATH}
  else
    LIBPATH=${JAVA_HOME_BIN}:${JAVA_HOME_CLASSIC}:${LIBPATH}
  fi

  # Add CLASSPATH info.
  CLASSPATH=
  CLASSPATH=

  # Add sslight
  if [ "$SSLIGHT"  != "" ] ; then
     CLASSPATH=${SSLIGHT}:${CLASSPATH}
  fi

  # Add key class path if specified
  if [ "$keyclass"  != "" ] ; then
     CLASSPATH=${keyclass}:${CLASSPATH}
  fi
  export CLASSPATH
fi

# 3) if this happens to be idsxcfg/idsxinst. We have a special case.
# have to CD to the directory and do a few more things.

# 4) Add the needed pieces to the PATH.
GetITDIHOME
TDI_HOME=${IDS_LDAP_TDI_HOME}
PATH=${IDS_LDAP_HOME}:${PATH}
PATH=${IDS_LDAP_HOME}/bin:${IDS_LDAP_HOME}/sbin:${PATH}
PATH=${TDI_HOME}:${TDI_HOME}/bin:${PATH}
PATH=${IDS_LDAP_HOME}/bin:${PATH}
export PATH
export TDI_HOME

# 5) we need to make sure the executables or JVM exists
# depending on the type of program it is.

# 6) Determine if we need 32 or 64 bit library directory.
if [ "${OS}" = "Linux" ] ; then
  # Assume 64-bit.
  ITDS_LIB=lib64
  ITDS_BIN=64

elif [ "${OS}" = "HP-UX" ] ; then
  # Assume 64-bit.
  ITDS_LIB=lib64
  ITDS_BIN=64

elif [ "${OS}" = "SunOS" ] ; then
  # Assume 64-bit.
  ITDS_LIB=lib64
  ITDS_BIN=64

else
  # This case is for AIX.
  # Assume 64-bit.
  ITDS_LIB=lib64
  ITDS_BIN=64

fi

# 7) we need to make sure the executable exist that we have
#    chosen to use.  This is a second check.

# 8) Set the library path.
# Add the DB2 library for IDS_LDAP_HOME to the path if needed.

# Add the IBM Tivoli Directory Server libraries
if [ "${OS}" = "Linux" ] ; then
  LD_LIBRARY_PATH=/usr/${ITDS_LIB}:${LD_LIBRARY_PATH}
  LD_LIBRARY_PATH=${IDS_LDAP_HOME}/${ITDS_LIB}:${LD_LIBRARY_PATH}:.
  ORIG_LD_LIBRARY_PATH=${LD_LIBRARY_PATH}
  export LD_LIBRARY_PATH
  export ORIG_LD_LIBRARY_PATH
elif [ "${OS}" = "HP-UX" ] ; then
  SHLIB_PATH=/usr/lib:${SHLIB_PATH}
  SHLIB_PATH=${IDS_LDAP_HOME}/${ITDS_LIB}:${SHLIB_PATH}:.
  ORIG_SHLIB_PATH=${SHLIB_PATH}
  LD_LIBRARY_PATH=${SHLIB_PATH}
  export SHLIB_PATH
  export ORIG_SHLIB_PATH
  export LD_LIBRARY_PATH
elif [ "${OS}" = "SunOS" ] ; then
  LD_LIBRARY_PATH=/usr/lib/64:/usr/lib/sparcv9:${LD_LIBRARY_PATH}
  LD_LIBRARY_PATH=${IDS_LDAP_HOME}/${ITDS_LIB}:${LD_LIBRARY_PATH}:.
  ORIG_LD_LIBRARY_PATH=${LD_LIBRARY_PATH}
  export LD_LIBRARY_PATH
  export ORIG_LD_LIBRARY_PATH
else
  LIBPATH=/usr/lib:${LIBPATH}
  LIBPATH=${IDS_LDAP_HOME}/${ITDS_LIB}:${LIBPATH}:.
  ORIG_LIBPATH=${LIBPATH}
  export LIBPATH
  export ORIG_LIBPATH
fi

# 8) Set the NLSPATH.
if [ "$NLSPATH"  != "" ] ; then
  NLSPATH=$IDS_LDAP_HOME/nls/msg/%L/%N:$IDS_LDAP_HOME/nls/msg/%L/%N.cat:${NLSPATH}
else
  NLSPATH=$IDS_LDAP_HOME/nls/msg/%L/%N:$IDS_LDAP_HOME/nls/msg/%L/%N.cat
fi
export NLSPATH

# 9) Set the TISDIR
export TISDIR=$IDS_LDAP_HOME

# 10) Now, run the program.

eval '${IDS_LDAP_PRE} ${ISAM_HOME}/sbin/$PROGNAME "$@"'
rc=$?

# 11) Return the return code from the executable.
exit $rc
